@@ -1,11 +1,8 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 """
 Optional Django REST Framework filter backends for the ``django-user-tasks`` REST API.
 """
 
-from __future__ import absolute_import, unicode_literals
-
 from rest_framework.filters import BaseFilterBackend
 
 
